{
    "$graph": [
        {
            "class": "Workflow",
            "label": "cram_to_bam workflow",
            "inputs": [
                {
                    "type": "File",
                    "secondaryFiles": [
                        "^.crai"
                    ],
                    "id": "#cram_to_bam_and_index.cwl/cram"
                },
                {
                    "type": "string",
                    "id": "#cram_to_bam_and_index.cwl/reference"
                }
            ],
            "steps": [
                {
                    "run": "#cram_to_bam.cwl",
                    "in": [
                        {
                            "source": "#cram_to_bam_and_index.cwl/cram",
                            "id": "#cram_to_bam_and_index.cwl/cram_to_bam/cram"
                        },
                        {
                            "source": "#cram_to_bam_and_index.cwl/reference",
                            "id": "#cram_to_bam_and_index.cwl/cram_to_bam/reference"
                        }
                    ],
                    "out": [
                        "#cram_to_bam_and_index.cwl/cram_to_bam/bam"
                    ],
                    "id": "#cram_to_bam_and_index.cwl/cram_to_bam"
                },
                {
                    "run": "#index_bam.cwl",
                    "in": [
                        {
                            "source": "#cram_to_bam_and_index.cwl/cram_to_bam/bam",
                            "id": "#cram_to_bam_and_index.cwl/index_bam/bam"
                        }
                    ],
                    "out": [
                        "#cram_to_bam_and_index.cwl/index_bam/indexed_bam"
                    ],
                    "id": "#cram_to_bam_and_index.cwl/index_bam"
                }
            ],
            "id": "#cram_to_bam_and_index.cwl",
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#cram_to_bam_and_index.cwl/index_bam/indexed_bam",
                    "secondaryFiles": [
                        ".bai"
                    ],
                    "id": "#cram_to_bam_and_index.cwl/bam"
                }
            ]
        },
        {
            "class": "Workflow",
            "label": "HS Metrics workflow",
            "requirements": [
                {
                    "class": "ScatterFeatureRequirement"
                },
                {
                    "class": "SchemaDefRequirement",
                    "types": [
                        {
                            "type": "record",
                            "name": "#labelled_file.yml/labelled_file",
                            "label": "a file with a label",
                            "fields": [
                                {
                                    "type": "File",
                                    "name": "#labelled_file.yml/labelled_file/file"
                                },
                                {
                                    "type": "string",
                                    "name": "#labelled_file.yml/labelled_file/label"
                                }
                            ]
                        }
                    ]
                },
                {
                    "class": "StepInputExpressionRequirement"
                },
                {
                    "class": "SubworkflowFeatureRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "secondaryFiles": [
                        "^.crai"
                    ],
                    "id": "#hs_metrics.cwl/cram"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "id": "#hs_metrics.cwl/minimum_base_quality"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "id": "#hs_metrics.cwl/minimum_mapping_quality"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "#labelled_file.yml/labelled_file"
                    },
                    "id": "#hs_metrics.cwl/per_base_intervals"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "#labelled_file.yml/labelled_file"
                    },
                    "id": "#hs_metrics.cwl/per_target_intervals"
                },
                {
                    "type": "string",
                    "id": "#hs_metrics.cwl/reference"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "#labelled_file.yml/labelled_file"
                    },
                    "id": "#hs_metrics.cwl/summary_intervals"
                }
            ],
            "outputs": [
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#hs_metrics.cwl/collect_per_base_hs_metrics/per_base_coverage_metrics",
                    "id": "#hs_metrics.cwl/per_base_coverage_metrics"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#hs_metrics.cwl/collect_per_base_hs_metrics/hs_metrics",
                    "id": "#hs_metrics.cwl/per_base_hs_metrics"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#hs_metrics.cwl/collect_per_target_hs_metrics/per_target_coverage_metrics",
                    "id": "#hs_metrics.cwl/per_target_coverage_metrics"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#hs_metrics.cwl/collect_per_target_hs_metrics/hs_metrics",
                    "id": "#hs_metrics.cwl/per_target_hs_metrics"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#hs_metrics.cwl/collect_summary_hs_metrics/hs_metrics",
                    "id": "#hs_metrics.cwl/summary_hs_metrics"
                }
            ],
            "steps": [
                {
                    "run": "#collect_hs_metrics.cwl",
                    "scatter": [
                        "#hs_metrics.cwl/collect_per_base_hs_metrics/bait_intervals",
                        "#hs_metrics.cwl/collect_per_base_hs_metrics/target_intervals",
                        "#hs_metrics.cwl/collect_per_base_hs_metrics/output_prefix"
                    ],
                    "scatterMethod": "dotproduct",
                    "in": [
                        {
                            "source": "#hs_metrics.cwl/per_base_intervals",
                            "valueFrom": "$(self.file)",
                            "id": "#hs_metrics.cwl/collect_per_base_hs_metrics/bait_intervals"
                        },
                        {
                            "source": "#hs_metrics.cwl/cram",
                            "id": "#hs_metrics.cwl/collect_per_base_hs_metrics/cram"
                        },
                        {
                            "valueFrom": "ALL_READS",
                            "id": "#hs_metrics.cwl/collect_per_base_hs_metrics/metric_accumulation_level"
                        },
                        {
                            "source": "#hs_metrics.cwl/minimum_base_quality",
                            "id": "#hs_metrics.cwl/collect_per_base_hs_metrics/minimum_base_quality"
                        },
                        {
                            "source": "#hs_metrics.cwl/minimum_mapping_quality",
                            "id": "#hs_metrics.cwl/collect_per_base_hs_metrics/minimum_mapping_quality"
                        },
                        {
                            "source": "#hs_metrics.cwl/per_base_intervals",
                            "valueFrom": "base-$(self.label)",
                            "id": "#hs_metrics.cwl/collect_per_base_hs_metrics/output_prefix"
                        },
                        {
                            "default": true,
                            "id": "#hs_metrics.cwl/collect_per_base_hs_metrics/per_base_coverage"
                        },
                        {
                            "default": false,
                            "id": "#hs_metrics.cwl/collect_per_base_hs_metrics/per_target_coverage"
                        },
                        {
                            "source": "#hs_metrics.cwl/reference",
                            "id": "#hs_metrics.cwl/collect_per_base_hs_metrics/reference"
                        },
                        {
                            "source": "#hs_metrics.cwl/per_base_intervals",
                            "valueFrom": "$(self.file)",
                            "id": "#hs_metrics.cwl/collect_per_base_hs_metrics/target_intervals"
                        }
                    ],
                    "out": [
                        "#hs_metrics.cwl/collect_per_base_hs_metrics/hs_metrics",
                        "#hs_metrics.cwl/collect_per_base_hs_metrics/per_base_coverage_metrics"
                    ],
                    "id": "#hs_metrics.cwl/collect_per_base_hs_metrics"
                },
                {
                    "run": "#collect_hs_metrics.cwl",
                    "scatter": [
                        "#hs_metrics.cwl/collect_per_target_hs_metrics/bait_intervals",
                        "#hs_metrics.cwl/collect_per_target_hs_metrics/target_intervals",
                        "#hs_metrics.cwl/collect_per_target_hs_metrics/output_prefix"
                    ],
                    "scatterMethod": "dotproduct",
                    "in": [
                        {
                            "source": "#hs_metrics.cwl/per_target_intervals",
                            "valueFrom": "$(self.file)",
                            "id": "#hs_metrics.cwl/collect_per_target_hs_metrics/bait_intervals"
                        },
                        {
                            "source": "#hs_metrics.cwl/cram",
                            "id": "#hs_metrics.cwl/collect_per_target_hs_metrics/cram"
                        },
                        {
                            "valueFrom": "ALL_READS",
                            "id": "#hs_metrics.cwl/collect_per_target_hs_metrics/metric_accumulation_level"
                        },
                        {
                            "source": "#hs_metrics.cwl/minimum_base_quality",
                            "id": "#hs_metrics.cwl/collect_per_target_hs_metrics/minimum_base_quality"
                        },
                        {
                            "source": "#hs_metrics.cwl/minimum_mapping_quality",
                            "id": "#hs_metrics.cwl/collect_per_target_hs_metrics/minimum_mapping_quality"
                        },
                        {
                            "source": "#hs_metrics.cwl/per_target_intervals",
                            "valueFrom": "target-$(self.label)",
                            "id": "#hs_metrics.cwl/collect_per_target_hs_metrics/output_prefix"
                        },
                        {
                            "default": false,
                            "id": "#hs_metrics.cwl/collect_per_target_hs_metrics/per_base_coverage"
                        },
                        {
                            "default": true,
                            "id": "#hs_metrics.cwl/collect_per_target_hs_metrics/per_target_coverage"
                        },
                        {
                            "source": "#hs_metrics.cwl/reference",
                            "id": "#hs_metrics.cwl/collect_per_target_hs_metrics/reference"
                        },
                        {
                            "source": "#hs_metrics.cwl/per_target_intervals",
                            "valueFrom": "$(self.file)",
                            "id": "#hs_metrics.cwl/collect_per_target_hs_metrics/target_intervals"
                        }
                    ],
                    "out": [
                        "#hs_metrics.cwl/collect_per_target_hs_metrics/hs_metrics",
                        "#hs_metrics.cwl/collect_per_target_hs_metrics/per_target_coverage_metrics"
                    ],
                    "id": "#hs_metrics.cwl/collect_per_target_hs_metrics"
                },
                {
                    "run": "#collect_hs_metrics.cwl",
                    "scatter": [
                        "#hs_metrics.cwl/collect_summary_hs_metrics/bait_intervals",
                        "#hs_metrics.cwl/collect_summary_hs_metrics/target_intervals",
                        "#hs_metrics.cwl/collect_summary_hs_metrics/output_prefix"
                    ],
                    "scatterMethod": "dotproduct",
                    "in": [
                        {
                            "source": "#hs_metrics.cwl/summary_intervals",
                            "valueFrom": "$(self.file)",
                            "id": "#hs_metrics.cwl/collect_summary_hs_metrics/bait_intervals"
                        },
                        {
                            "source": "#hs_metrics.cwl/cram",
                            "id": "#hs_metrics.cwl/collect_summary_hs_metrics/cram"
                        },
                        {
                            "valueFrom": "ALL_READS",
                            "id": "#hs_metrics.cwl/collect_summary_hs_metrics/metric_accumulation_level"
                        },
                        {
                            "source": "#hs_metrics.cwl/minimum_base_quality",
                            "id": "#hs_metrics.cwl/collect_summary_hs_metrics/minimum_base_quality"
                        },
                        {
                            "source": "#hs_metrics.cwl/minimum_mapping_quality",
                            "id": "#hs_metrics.cwl/collect_summary_hs_metrics/minimum_mapping_quality"
                        },
                        {
                            "source": "#hs_metrics.cwl/summary_intervals",
                            "valueFrom": "summary-$(self.label)",
                            "id": "#hs_metrics.cwl/collect_summary_hs_metrics/output_prefix"
                        },
                        {
                            "default": false,
                            "id": "#hs_metrics.cwl/collect_summary_hs_metrics/per_base_coverage"
                        },
                        {
                            "default": false,
                            "id": "#hs_metrics.cwl/collect_summary_hs_metrics/per_target_coverage"
                        },
                        {
                            "source": "#hs_metrics.cwl/reference",
                            "id": "#hs_metrics.cwl/collect_summary_hs_metrics/reference"
                        },
                        {
                            "source": "#hs_metrics.cwl/summary_intervals",
                            "valueFrom": "$(self.file)",
                            "id": "#hs_metrics.cwl/collect_summary_hs_metrics/target_intervals"
                        }
                    ],
                    "out": [
                        "#hs_metrics.cwl/collect_summary_hs_metrics/hs_metrics"
                    ],
                    "id": "#hs_metrics.cwl/collect_summary_hs_metrics"
                }
            ],
            "id": "#hs_metrics.cwl"
        },
        {
            "class": "Workflow",
            "label": "WGS QC workflow",
            "requirements": [
                {
                    "class": "SchemaDefRequirement",
                    "types": [
                        {
                            "$import": "#labelled_file.yml/labelled_file"
                        }
                    ]
                },
                {
                    "class": "SubworkflowFeatureRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "secondaryFiles": [
                        "^.crai"
                    ],
                    "id": "#main/cram"
                },
                {
                    "type": "File",
                    "id": "#main/intervals"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "id": "#main/minimum_base_quality"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "id": "#main/minimum_mapping_quality"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#main/omni_vcf"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "#labelled_file.yml/labelled_file"
                    },
                    "id": "#main/per_base_intervals"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "#labelled_file.yml/labelled_file"
                    },
                    "id": "#main/per_target_intervals"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "default": "ALL_READS",
                    "id": "#main/picard_metric_accumulation_level"
                },
                {
                    "type": "string",
                    "id": "#main/reference"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "#labelled_file.yml/labelled_file"
                    },
                    "id": "#main/summary_intervals"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#main/collect_alignment_summary_metrics/alignment_summary_metrics",
                    "id": "#main/alignment_summary_metrics"
                },
                {
                    "type": "File",
                    "outputSource": "#main/samtools_flagstat/flagstats",
                    "id": "#main/flagstats"
                },
                {
                    "type": "File",
                    "outputSource": "#main/collect_gc_bias_metrics/gc_bias_metrics",
                    "id": "#main/gc_bias_metrics"
                },
                {
                    "type": "File",
                    "outputSource": "#main/collect_gc_bias_metrics/gc_bias_metrics_chart",
                    "id": "#main/gc_bias_metrics_chart"
                },
                {
                    "type": "File",
                    "outputSource": "#main/collect_gc_bias_metrics/gc_bias_metrics_summary",
                    "id": "#main/gc_bias_metrics_summary"
                },
                {
                    "type": "File",
                    "outputSource": "#main/collect_insert_size_metrics/insert_size_histogram",
                    "id": "#main/insert_size_histogram"
                },
                {
                    "type": "File",
                    "outputSource": "#main/collect_insert_size_metrics/insert_size_metrics",
                    "id": "#main/insert_size_metrics"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#main/collect_hs_metrics/per_base_coverage_metrics",
                    "id": "#main/per_base_coverage_metrics"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#main/collect_hs_metrics/per_base_hs_metrics",
                    "id": "#main/per_base_hs_metrics"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#main/collect_hs_metrics/per_target_coverage_metrics",
                    "id": "#main/per_target_coverage_metrics"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#main/collect_hs_metrics/per_target_hs_metrics",
                    "id": "#main/per_target_hs_metrics"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#main/collect_hs_metrics/summary_hs_metrics",
                    "id": "#main/summary_hs_metrics"
                },
                {
                    "type": "File",
                    "outputSource": "#main/verify_bam_id/verify_bam_id_depth",
                    "id": "#main/verify_bam_id_depth"
                },
                {
                    "type": "File",
                    "outputSource": "#main/verify_bam_id/verify_bam_id_metrics",
                    "id": "#main/verify_bam_id_metrics"
                },
                {
                    "type": "File",
                    "outputSource": "#main/collect_wgs_metrics/wgs_metrics",
                    "id": "#main/wgs_metrics"
                }
            ],
            "steps": [
                {
                    "run": "#collect_alignment_summary_metrics.cwl",
                    "in": [
                        {
                            "source": "#main/cram",
                            "id": "#main/collect_alignment_summary_metrics/cram"
                        },
                        {
                            "source": "#main/picard_metric_accumulation_level",
                            "id": "#main/collect_alignment_summary_metrics/metric_accumulation_level"
                        },
                        {
                            "source": "#main/reference",
                            "id": "#main/collect_alignment_summary_metrics/reference"
                        }
                    ],
                    "out": [
                        "#main/collect_alignment_summary_metrics/alignment_summary_metrics"
                    ],
                    "id": "#main/collect_alignment_summary_metrics"
                },
                {
                    "run": "#collect_gc_bias_metrics.cwl",
                    "in": [
                        {
                            "source": "#main/cram",
                            "id": "#main/collect_gc_bias_metrics/cram"
                        },
                        {
                            "source": "#main/picard_metric_accumulation_level",
                            "id": "#main/collect_gc_bias_metrics/metric_accumulation_level"
                        },
                        {
                            "source": "#main/reference",
                            "id": "#main/collect_gc_bias_metrics/reference"
                        }
                    ],
                    "out": [
                        "#main/collect_gc_bias_metrics/gc_bias_metrics",
                        "#main/collect_gc_bias_metrics/gc_bias_metrics_chart",
                        "#main/collect_gc_bias_metrics/gc_bias_metrics_summary"
                    ],
                    "id": "#main/collect_gc_bias_metrics"
                },
                {
                    "run": "#hs_metrics.cwl",
                    "in": [
                        {
                            "source": "#main/cram",
                            "id": "#main/collect_hs_metrics/cram"
                        },
                        {
                            "source": "#main/minimum_base_quality",
                            "id": "#main/collect_hs_metrics/minimum_base_quality"
                        },
                        {
                            "source": "#main/minimum_mapping_quality",
                            "id": "#main/collect_hs_metrics/minimum_mapping_quality"
                        },
                        {
                            "source": "#main/per_base_intervals",
                            "id": "#main/collect_hs_metrics/per_base_intervals"
                        },
                        {
                            "source": "#main/per_target_intervals",
                            "id": "#main/collect_hs_metrics/per_target_intervals"
                        },
                        {
                            "source": "#main/reference",
                            "id": "#main/collect_hs_metrics/reference"
                        },
                        {
                            "source": "#main/summary_intervals",
                            "id": "#main/collect_hs_metrics/summary_intervals"
                        }
                    ],
                    "out": [
                        "#main/collect_hs_metrics/per_base_coverage_metrics",
                        "#main/collect_hs_metrics/per_base_hs_metrics",
                        "#main/collect_hs_metrics/per_target_coverage_metrics",
                        "#main/collect_hs_metrics/per_target_hs_metrics",
                        "#main/collect_hs_metrics/summary_hs_metrics"
                    ],
                    "id": "#main/collect_hs_metrics"
                },
                {
                    "run": "#collect_insert_size_metrics.cwl",
                    "in": [
                        {
                            "source": "#main/cram",
                            "id": "#main/collect_insert_size_metrics/cram"
                        },
                        {
                            "source": "#main/picard_metric_accumulation_level",
                            "id": "#main/collect_insert_size_metrics/metric_accumulation_level"
                        },
                        {
                            "source": "#main/reference",
                            "id": "#main/collect_insert_size_metrics/reference"
                        }
                    ],
                    "out": [
                        "#main/collect_insert_size_metrics/insert_size_metrics",
                        "#main/collect_insert_size_metrics/insert_size_histogram"
                    ],
                    "id": "#main/collect_insert_size_metrics"
                },
                {
                    "run": "#collect_wgs_metrics.cwl",
                    "in": [
                        {
                            "source": "#main/cram",
                            "id": "#main/collect_wgs_metrics/cram"
                        },
                        {
                            "source": "#main/intervals",
                            "id": "#main/collect_wgs_metrics/intervals"
                        },
                        {
                            "source": "#main/reference",
                            "id": "#main/collect_wgs_metrics/reference"
                        }
                    ],
                    "out": [
                        "#main/collect_wgs_metrics/wgs_metrics"
                    ],
                    "id": "#main/collect_wgs_metrics"
                },
                {
                    "run": "#cram_to_bam_and_index.cwl",
                    "in": [
                        {
                            "source": "#main/cram",
                            "id": "#main/cram_to_bam/cram"
                        },
                        {
                            "source": "#main/reference",
                            "id": "#main/cram_to_bam/reference"
                        }
                    ],
                    "out": [
                        "#main/cram_to_bam/bam"
                    ],
                    "id": "#main/cram_to_bam"
                },
                {
                    "run": "#samtools_flagstat.cwl",
                    "in": [
                        {
                            "source": "#main/cram",
                            "id": "#main/samtools_flagstat/cram"
                        }
                    ],
                    "out": [
                        "#main/samtools_flagstat/flagstats"
                    ],
                    "id": "#main/samtools_flagstat"
                },
                {
                    "run": "#verify_bam_id.cwl",
                    "in": [
                        {
                            "source": "#main/cram_to_bam/bam",
                            "id": "#main/verify_bam_id/bam"
                        },
                        {
                            "source": "#main/omni_vcf",
                            "id": "#main/verify_bam_id/vcf"
                        }
                    ],
                    "out": [
                        "#main/verify_bam_id/verify_bam_id_metrics",
                        "#main/verify_bam_id/verify_bam_id_depth"
                    ],
                    "id": "#main/verify_bam_id"
                }
            ],
            "id": "#main"
        },
        {
            "class": "CommandLineTool",
            "label": "collect alignment summary metrics",
            "baseCommand": [
                "/usr/bin/java",
                "-Xmx16g",
                "-jar",
                "/usr/picard/picard.jar",
                "CollectAlignmentSummaryMetrics"
            ],
            "arguments": [
                "OUTPUT=",
                {
                    "valueFrom": "$(runtime.outdir)/$(inputs.cram.nameroot).AlignmentSummaryMetrics.txt"
                }
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 16000
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "mgibio/picard-cwl:2.18.1"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "INPUT="
                    },
                    "secondaryFiles": [
                        "^.crai"
                    ],
                    "id": "#collect_alignment_summary_metrics.cwl/cram"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "METRIC_ACCUMULATION_LEVEL="
                    },
                    "id": "#collect_alignment_summary_metrics.cwl/metric_accumulation_level"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "REFERENCE_SEQUENCE="
                    },
                    "id": "#collect_alignment_summary_metrics.cwl/reference"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.cram.nameroot).AlignmentSummaryMetrics.txt"
                    },
                    "id": "#collect_alignment_summary_metrics.cwl/alignment_summary_metrics"
                }
            ],
            "id": "#collect_alignment_summary_metrics.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "collect gc bias metrics",
            "baseCommand": [
                "/usr/bin/java",
                "-Xmx16g",
                "-jar",
                "/usr/picard/picard.jar",
                "CollectGcBiasMetrics"
            ],
            "arguments": [
                "O=",
                {
                    "valueFrom": "$(runtime.outdir)/GcBiasMetrics.txt"
                },
                "CHART=",
                {
                    "valueFrom": "$(runtime.outdir)/GcBiasMetricsChart.pdf"
                },
                "S=",
                {
                    "valueFrom": "$(runtime.outdir)/GcBiasMetricsSummary.txt"
                }
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 16000
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "mgibio/cle"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "I="
                    },
                    "secondaryFiles": [
                        "^.crai"
                    ],
                    "id": "#collect_gc_bias_metrics.cwl/cram"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "METRIC_ACCUMULATION_LEVEL="
                    },
                    "id": "#collect_gc_bias_metrics.cwl/metric_accumulation_level"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "R="
                    },
                    "id": "#collect_gc_bias_metrics.cwl/reference"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "GcBiasMetrics.txt"
                    },
                    "id": "#collect_gc_bias_metrics.cwl/gc_bias_metrics"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "GcBiasMetricsChart.pdf"
                    },
                    "id": "#collect_gc_bias_metrics.cwl/gc_bias_metrics_chart"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "GcBiasMetricsSummary.txt"
                    },
                    "id": "#collect_gc_bias_metrics.cwl/gc_bias_metrics_summary"
                }
            ],
            "id": "#collect_gc_bias_metrics.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "collect HS metrics",
            "baseCommand": [
                "/usr/bin/java",
                "-Xmx16g",
                "-jar",
                "/usr/picard/picard.jar",
                "CollectHsMetrics"
            ],
            "arguments": [
                "O=",
                {
                    "valueFrom": "$(runtime.outdir)/$(inputs.cram.nameroot).$(inputs.output_prefix)-HsMetrics.txt"
                }
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 16000
                },
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "mgibio/picard-cwl:2.18.1"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "BAIT_INTERVALS="
                    },
                    "id": "#collect_hs_metrics.cwl/bait_intervals"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "I="
                    },
                    "secondaryFiles": [
                        "^.crai"
                    ],
                    "id": "#collect_hs_metrics.cwl/cram"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "METRIC_ACCUMULATION_LEVEL="
                    },
                    "id": "#collect_hs_metrics.cwl/metric_accumulation_level"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "default": 1,
                    "inputBinding": {
                        "prefix": "MINIMUM_BASE_QUALITY="
                    },
                    "id": "#collect_hs_metrics.cwl/minimum_base_quality"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "default": 1,
                    "inputBinding": {
                        "prefix": "MINIMUM_MAPPING_QUALITY="
                    },
                    "id": "#collect_hs_metrics.cwl/minimum_mapping_quality"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "default": "out",
                    "id": "#collect_hs_metrics.cwl/output_prefix"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "prefix": "PER_BASE_COVERAGE=",
                        "valueFrom": "${\n    if(self) {\n        return inputs.cram.nameroot + \".\" + inputs.output_prefix + \"-PerBaseCoverage.txt\"\n    } else {\n        return false;\n    }\n}\n"
                    },
                    "id": "#collect_hs_metrics.cwl/per_base_coverage"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "prefix": "PER_TARGET_COVERAGE=",
                        "valueFrom": "${\n    if(self) {\n        return inputs.cram.nameroot + \".\" + inputs.output_prefix + \"-PerTargetCoverage.txt\"\n    } else {\n        return false;\n    }\n}\n"
                    },
                    "id": "#collect_hs_metrics.cwl/per_target_coverage"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "R="
                    },
                    "id": "#collect_hs_metrics.cwl/reference"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "TARGET_INTERVALS="
                    },
                    "id": "#collect_hs_metrics.cwl/target_intervals"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.cram.nameroot).$(inputs.output_prefix)-HsMetrics.txt"
                    },
                    "id": "#collect_hs_metrics.cwl/hs_metrics"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "$(inputs.cram.nameroot).$(inputs.output_prefix)-PerBaseCoverage.txt"
                    },
                    "id": "#collect_hs_metrics.cwl/per_base_coverage_metrics"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "$(inputs.cram.nameroot).$(inputs.output_prefix)-PerTargetCoverage.txt"
                    },
                    "id": "#collect_hs_metrics.cwl/per_target_coverage_metrics"
                }
            ],
            "id": "#collect_hs_metrics.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "collect insert size metrics",
            "baseCommand": [
                "/usr/bin/java",
                "-Xmx16g",
                "-jar",
                "/usr/picard/picard.jar",
                "CollectInsertSizeMetrics"
            ],
            "arguments": [
                "O=",
                {
                    "valueFrom": "$(runtime.outdir)/$(inputs.cram.nameroot).InsertSizeMetrics.txt"
                },
                "H=",
                {
                    "valueFrom": "$(runtime.outdir)/$(inputs.cram.nameroot).InsertSizeHistogram.pdf"
                }
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 16000
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "mgibio/picard-cwl:2.18.1"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "I="
                    },
                    "secondaryFiles": [
                        "^.crai"
                    ],
                    "id": "#collect_insert_size_metrics.cwl/cram"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "METRIC_ACCUMULATION_LEVEL="
                    },
                    "id": "#collect_insert_size_metrics.cwl/metric_accumulation_level"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "REFERENCE_SEQUENCE="
                    },
                    "id": "#collect_insert_size_metrics.cwl/reference"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.cram.nameroot).InsertSizeHistogram.pdf"
                    },
                    "id": "#collect_insert_size_metrics.cwl/insert_size_histogram"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.cram.nameroot).InsertSizeMetrics.txt"
                    },
                    "id": "#collect_insert_size_metrics.cwl/insert_size_metrics"
                }
            ],
            "id": "#collect_insert_size_metrics.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "collect WGS metrics",
            "baseCommand": [
                "/usr/bin/java",
                "-Xmx16g",
                "-jar",
                "/usr/picard/picard.jar",
                "CollectWgsMetrics"
            ],
            "arguments": [
                "O=",
                {
                    "valueFrom": "$(runtime.outdir)/WgsMetrics.txt"
                }
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 16000
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "mgibio/cle"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "I="
                    },
                    "secondaryFiles": [
                        "^.crai"
                    ],
                    "id": "#collect_wgs_metrics.cwl/cram"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "INTERVALS="
                    },
                    "id": "#collect_wgs_metrics.cwl/intervals"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "R="
                    },
                    "id": "#collect_wgs_metrics.cwl/reference"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "WgsMetrics.txt"
                    },
                    "id": "#collect_wgs_metrics.cwl/wgs_metrics"
                }
            ],
            "id": "#collect_wgs_metrics.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "samtools view cram to bam",
            "baseCommand": [
                "/opt/samtools/bin/samtools",
                "view",
                "-b"
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 4000
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "mgibio/samtools-cwl:1.0.0"
                }
            ],
            "arguments": [
                "-o",
                {
                    "valueFrom": "$(runtime.outdir)/$(inputs.cram.nameroot).bam"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 2
                    },
                    "secondaryFiles": [
                        "^.crai"
                    ],
                    "id": "#cram_to_bam.cwl/cram"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "-T",
                        "position": 1
                    },
                    "id": "#cram_to_bam.cwl/reference"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.cram.nameroot).bam"
                    },
                    "id": "#cram_to_bam.cwl/bam"
                }
            ],
            "id": "#cram_to_bam.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "samtools index",
            "arguments": [
                "cp",
                "$(inputs.bam.path)",
                "$(runtime.outdir)/$(inputs.bam.basename)",
                {
                    "valueFrom": " && ",
                    "shellQuote": false
                },
                "/opt/samtools/bin/samtools",
                "index",
                "$(inputs.bam.path)",
                "$(runtime.outdir)/$(inputs.bam.basename).bai"
            ],
            "requirements": [
                {
                    "class": "ShellCommandRequirement"
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "mgibio/samtools-cwl:1.0.0"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "id": "#index_bam.cwl/bam"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".bai"
                    ],
                    "outputBinding": {
                        "glob": "$(inputs.bam.basename)"
                    },
                    "id": "#index_bam.cwl/indexed_bam"
                }
            ],
            "id": "#index_bam.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "samtools flagstat",
            "baseCommand": [
                "/opt/samtools/bin/samtools",
                "flagstat"
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 4000
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "mgibio/samtools-cwl:1.0.0"
                }
            ],
            "stdout": "$(inputs.cram.basename).flagstat",
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1
                    },
                    "secondaryFiles": [
                        "^.crai"
                    ],
                    "id": "#samtools_flagstat.cwl/cram"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "id": "#samtools_flagstat.cwl/flagstats",
                    "outputBinding": {
                        "glob": "$(inputs.cram.basename).flagstat"
                    }
                }
            ],
            "id": "#samtools_flagstat.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "verify BAM ID",
            "baseCommand": "/usr/local/bin/verifyBamID",
            "arguments": [
                "--out",
                {
                    "valueFrom": "$(runtime.outdir)/$(inputs.bam.nameroot).VerifyBamId"
                }
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 4000
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "mgibio/verify_bam_id-cwl:1.1.3"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "--bam"
                    },
                    "id": "#verify_bam_id.cwl/bam"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "--vcf"
                    },
                    "id": "#verify_bam_id.cwl/vcf"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.bam.nameroot).VerifyBamId.depthSM"
                    },
                    "id": "#verify_bam_id.cwl/verify_bam_id_depth"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.bam.nameroot).VerifyBamId.selfSM"
                    },
                    "id": "#verify_bam_id.cwl/verify_bam_id_metrics"
                }
            ],
            "id": "#verify_bam_id.cwl"
        }
    ],
    "cwlVersion": "v1.0"
}
